Learn R Programming

hydrogeo (version 0.2-3)

piper-class: Class "piper"

Description

Objects of this class are plotable as Piper-Hill diagrams. A dataframe of major ions as percentages can be used to initialise a piper object.

Arguments

Objects from the Class

Objects can be created by calls of the form: new("piper", l, call, size, group, colours, numbersymbols, wt.col, wt.pch, pt.col), or, piper(dataframe)

References

A. Zaporozec, ``Graphical interpretation of water quality data,'' Ground Water 10, no. 2 (1972): 32--43.

Examples

Run this code
showClass("piper")

library(hydrogeo)

l <- list( Ca = c(43,10,73,26,32),
           Mg = c(30,50,3,14,12),
           Cl = c(24,10,12,30,43),
           SO4 = c(24,10,12,30,43),
           WaterType = c(2,2,1,2,3),
           IDs = c("A","B","C","D","E") )
l$pt.pch <- c(2,1,1,3,4)

lp<-piper(l)
plot( lp, main="Piper-Hill Diagram of Water Quality" )

p <- new("piper",l)
plot( p, main="Piper-Hill Diagram of Water Quality" )

Run the code above in your browser using DataLab